package jat.validators;

import java.text.MessageFormat;

import javax.faces.application.FacesMessage;
import javax.faces.bean.ApplicationScoped;
import javax.faces.bean.ManagedBean;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.validator.Validator;
import javax.faces.validator.ValidatorException;

import jat.dto.Person;
import jat.dto.StarShip;
import jat.fakeDB.StarShipDB;
import jat.managedbeans.PersonMB;

@ManagedBean
@ApplicationScoped
public class ShipCapacityValidator implements Validator {

	@Override
	public void validate(FacesContext context, UIComponent component, Object value) throws ValidatorException {
		if (value == null) {
			context.addMessage(component.getClientId(),
					new FacesMessage(FacesMessage.SEVERITY_WARN,
							getMessage(context, "jat.validators.ShipCapacityValidator.NO_SHIP",
									component.getAttributes().get("label")),
							getMessage(context, "jat.validators.ShipCapacityValidator.NO_SHIP_DETAIL",
									component.getAttributes().get("label"))));
		} else if (value instanceof StarShip) {
			StarShip s = (StarShip) value;
			PersonMB personMB = (PersonMB) context.getApplication().getELResolver().getValue(context.getELContext(),
					null, "personMB");
			if (s.getCrewMembers().size() >= s.getCrewCapacity() && (personMB.getEdited().getShip() == null
					|| personMB.getEdited().getShip().getId() != s.getId())) {
				FacesMessage message = new FacesMessage(FacesMessage.SEVERITY_ERROR,
						getMessage(context, "jat.validators.ShipCapacityValidator.NO_FREE_SPACE",
								component.getAttributes().get("label"), s.getCrewCapacity(), s.getCrewMembers().size()),
						getMessage(context, "jat.validators.ShipCapacityValidator.NO_FREE_SPACE_DETAIL",
								component.getAttributes().get("label"), s.getCrewCapacity(),
								s.getCrewMembers().size()));
				throw new ValidatorException(message);
			}
		} else {
			FacesMessage message = new FacesMessage(FacesMessage.SEVERITY_ERROR,
					getMessage(context, "jat.validators.ShipCapacityValidator.NO_SUPPORTED_OBJECT_TYPE",
							component.getAttributes().get("label")),
					getMessage(context, "jat.validators.ShipCapacityValidator.NO_SUPPORTED_OBJECT_TYPE_DETAIL",
							component.getAttributes().get("label")));
			throw new ValidatorException(message);
		}
	}

	public String getMessage(FacesContext context, String key, Object... arguments) {
		String message = context.getApplication().getResourceBundle(context, "msg").getString(key);
		return MessageFormat.format(message, arguments);
	}

}
